summaryrefslogtreecommitdiff
path: root/round-robin-bisect.sh
diff options
context:
space:
mode:
Diffstat (limited to 'round-robin-bisect.sh')
-rwxr-xr-xround-robin-bisect.sh15
1 files changed, 6 insertions, 9 deletions
diff --git a/round-robin-bisect.sh b/round-robin-bisect.sh
index 8e682cd5..600fc6b9 100755
--- a/round-robin-bisect.sh
+++ b/round-robin-bisect.sh
@@ -89,8 +89,8 @@ EOF
ln -f -s "build-baseline" "$artifacts/build-$baseline_rev"
ln -f -s "build-baseline.sh" "$artifacts/manifests/build-$baseline_rev.sh"
-case "${rr[ci_project]}/${rr[ci_config]}" in
- tcwg_gnu/*-check_*|tcwg_cross/*-check_*)
+case "${rr[ci_project]}" in
+ tcwg_gcc_check*|tcwg_gnu_*_check_*)
(
# Build up lists of flaky tests. We do this by comparing
# just-created baseline vs sumfiles in base-artifacts.
@@ -803,13 +803,13 @@ fi
CI_MAIL_RECIPIENTS=("tcwg-validation@linaro.org")
case "$notify_author@${rr[ci_project]}/${rr[ci_config]}:$current_project" in
""@*/*:*) ;;
*@tcwg_gnu/*-check_bootstrap*:*) ;; # We are building up list of flaky tests
*@tcwg_cross/*-check_cross:*) ;; # We are building up list of flaky tests
*@tcwg_gnu/*:*)
CI_MAIL_RECIPIENTS+=("$notify_author")
CI_MAIL_RECIPIENTS+=("linaro-toolchain@lists.linaro.org")
;;
- *@tcwg_cross/*:*)
+ *@tcwg_gnu*/*:*)
CI_MAIL_RECIPIENTS+=("$notify_author")
CI_MAIL_RECIPIENTS+=("linaro-toolchain@lists.linaro.org")
;;
@@ -824,9 +824,6 @@ case "$notify_author@${rr[ci_project]}/${rr[ci_config]}:$current_project" in
CI_MAIL_RECIPIENTS+=("linaro-toolchain@lists.linaro.org")
CI_MAIL_RECIPIENTS+=("clang-built-linux@googlegroups.com")
;;
- *@tcwg_bmk*/gnu_eabi*:*)
- # Bare-metal benchmarking needs fixing
- ;;
*@tcwg_bmk*/*:*)
# Don't notify patch authors until we improve benchmarking email
# reporting.
@@ -803,13 +803,13 @@ fi
case "$notify_author@${rr[ci_project]}/${rr[ci_config]}:$current_project" in
""@*/*:*) ;;
- *@tcwg_gnu/*-check_bootstrap*:*) ;; # We are building up list of flaky tests
- *@tcwg_cross/*-check_cross:*) ;; # We are building up list of flaky tests
- *@tcwg_gnu/*:*)
+ *@tcwg_gcc_check*/*:*) ;; # We are building up list of flaky tests
+ *@tcwg_gnu_*_check_*/*:*) ;; # We are building up list of flaky tests
+ *@tcwg_gcc*/*:*)
CI_MAIL_RECIPIENTS+=("$notify_author")
CI_MAIL_RECIPIENTS+=("linaro-toolchain@lists.linaro.org")